import commonjs from 'rollup-plugin-commonjs';
import resolve from 'rollup-plugin-node-resolve';
import babel from 'rollup-plugin-babel';
import postcss from 'rollup-plugin-postcss';
import json from 'rollup-plugin-json';
import sourceMaps from 'rollup-plugin-sourcemaps';
import camelCase from 'lodash.camelcase';
//import rpt from 'rollup-plugin-typescript';
import rpt2 from 'rollup-plugin-typescript2';
import typescript from 'typescript';

import pkg from './package.json';

const extensions = ['.js', '.jsx', '.ts', '.tsx'];

const libraryName = 'enchoice-fabric-react-lib';

export default [
  {
    input: './src/lib/index.tsx',
    output: [
      {
        file: pkg.main,
        name: camelCase(libraryName),
        format: 'umd',
        sourcemap: true,
        globals: {
          react: 'React',
          'react-dom': 'ReactDOM'
        }
      },
      { file: pkg.module, format: 'es', sourcemap: true }
    ],
    // Specify here external modules which you don't want to include in your bundle (for instance: 'lodash', 'moment' etc.)
    // https://rollupjs.org/guide/en#external-e-external
    external: Object.keys(pkg.dependencies),

    plugins: [
      postcss({
        //  extract: true
        inject: true
      }),
      // Allow json resolution
      json(),

      rpt2({
        verbosity: 3,
        typescript: typescript,
        useTsconfigDeclarationDir: false,
        tsconfigOverride: { compilerOptions: { declaration: true, isolatedModules: false } }
      }),
      // Compile TypeScript/JavaScript files
      babel({ extensions, exclude: 'node_modules/**' }),

      //rpt({ typescript: typescript, tsconfig: false, outDir: 'dist2', declaration: true, declarationDir: 'dist/types' }),

      /*     ts({
        transpiler: 'babel',
        tsconfig: { declaration: true }
      }), */
      // Allows node_modules resolution
      resolve({ extensions, preferBuiltins: true }),

      // Allow bundling cjs modules. Rollup doesn't understand cjs
      commonjs({ include: 'node_modules/**' }),

      // Resolve source maps to the original source
      sourceMaps()
    ]
  }
];
