import * as React from 'react';
import './App.css';

import { IColumn } from 'office-ui-fabric-react/lib/DetailsList';

import { Fabric } from 'office-ui-fabric-react/lib/Fabric';

import { List } from './lib';
import SearchBoxDemo from './demo/SearchBoxDemo';

import {
  TemplateAdminForm,
  ITemplateAdminMainRow,
  ITemplateAdminPropertiesRow,
  OperatorsSettingsArrayEnum,
  ITemplateAdminFormObject
} from './lib';

import 'office-ui-fabric-react/dist/css/fabric.min.css';

const URL_BASE = 'http://localhost:3004/';
const URL_EDIT = 'http://localhost:3004/search-template-admin-edit-';
const GET_PROPERTIES_URL = 'template-properties';
const GET_PROPERTIES_DETAILS_URL = 'http://localhost:3004/search-template-admin-property';

class App extends React.Component<any, any> {
  constructor(props: any) {
    super(props);
    this.getUrl = this.getUrl.bind(this);
    this.onCustomBuildColumns = this.onCustomBuildColumns.bind(this);
    this.handleResponse = this.handleResponse.bind(this);
  }

  public render() {
    return (
      <Fabric className="App">
        <header className="App-header">
          <h1 className="App-title">Enchoice Fabric React components Library</h1>
        </header>
        <div className="ms-Grid-row">
          <div className="ms-Grid-col ms-sm6 ms-md6 ms-lg6">
            <h3>TemplateAdminForm in edit Mode</h3>
          </div>
          <div className="ms-Grid-col ms-sm2 ms-md2 ms-lg2">
            <h3>SearchBox</h3>
          </div>
          <div className="ms-Grid-col ms-sm4 ms-md4 ms-lg4">
            <h3>Infinite Scrolling List</h3>
          </div>
        </div>
        <div className="ms-Grid-row">
          <div className="ms-Grid-col ms-sm6 ms-md6 ms-lg6">
            <TemplateAdminForm
              baseUrl={URL_EDIT}
              user="Admin"
              id="1"
              onSubmitSuccess={response => console.log(response)}
              onSubmitError={response => console.log(response)}
              onCancel={() => console.log('Cancel')}
              getPropertiesDetailsUrl={() => `${GET_PROPERTIES_DETAILS_URL}`}
            />
          </div>
          <div className="ms-Grid-col ms-sm2 ms-md2 ms-lg2">
            <SearchBoxDemo />
          </div>
          <div className="ms-Grid-col ms-sm4 ms-md4 ms-lg4">
            <List
              getUrl={this.getUrl}
              handleResponse={this.handleResponse}
              onCustomBuildColumns={this.onCustomBuildColumns}
              height={'100vh'}
            />
          </div>
        </div>
      </Fabric>
    );
  }

  private getPropertiesUrl(search: string, page: number, sortBy?: string, sortDesc?: boolean): string {
    const sortDescValue = sortDesc ? 'desc' : 'asc';
    page = page === 0 ? 1 : page;
    return `${URL_BASE}${GET_PROPERTIES_URL}?_start=${page}&_limit=20&_sort=${sortBy}&_sortDesc=${sortDescValue}`;
  }

  private isNull(value: any) {
    return value == null || value === 'null' || value == undefined;
  }

  private getUrl(search: string, page: number, sortBy?: string, sortDesc?: boolean) {
    const qValue = this.isNull(search) ? '' : `&q=${search}`;
    const sortByValue = this.isNull(sortBy) ? '' : `&_sort=${sortBy}`;
    let sortDescValue = '';

    if (!this.isNull(sortDesc)) {
      sortDescValue = sortDesc ? '&_order=desc' : '&_order=asc';
    }

    const url = `http://localhost:5000/api/documents?_start=${page}&_limit=20${qValue}${sortByValue}${sortDescValue}`;
    console.log(url);
    return url;
  }

  private handleResponse(items) {
    return items;
  }

  private onCustomBuildColumns(): IColumn[] {
    console.log('custom columns');
    return [
      {
        key: 'Barcode',
        name: 'Barcode',
        fieldName: 'Barcode',
        minWidth: 210,
        maxWidth: 350,
        isRowHeader: true,
        isResizable: false,
        isSorted: true,
        isSortedDescending: false,
        sortAscendingAriaLabel: 'Sorted A to Z',
        sortDescendingAriaLabel: 'Sorted Z to A',
        data: 'string',
        isPadded: true
      }
    ];
  }
}

export default App;
