import * as React from 'react';
import '../App.css';

import { IColumn, IGroup } from 'office-ui-fabric-react/lib/DetailsList';

import { SearchBox, ISearchBoxGroupItems, ISearchBoxGroupItem } from '../lib';
import { IconButton, BaseButton, Button } from 'office-ui-fabric-react';

import update from 'immutability-helper';
import Axios from 'axios';

export interface ISearchBoxDemoState {
  groupItems: ISearchBoxGroupItems[];
  items: any[];
  groups: IGroup[];
}

class SearchBoxDemo extends React.Component<any, ISearchBoxDemoState> {
  constructor(props: any) {
    super(props);
    this.state = {
      items: [],
      groups: [],
      groupItems: []
    };

    this.loadRecentSearchs = this.loadRecentSearchs.bind(this);
    this.onRenderRecent = this.onRenderRecent.bind(this);
    this.addFavClick = this.addFavClick.bind(this);
  }

  public render() {
    return (
      <SearchBox
        placeholder="Custom placeholder"
        value="Default Value"
        underlined={true}
        onSearch={this.onSearch}
        onChange={this.onChange}
        onBlur={this.onBlur}
        onFocus={this.onFocus}
        onClear={this.onClear}
        onEscape={this.onEscape}
        groupItems={this.state.groupItems}
      />
    );
  }

  public componentDidMount() {
    this.loadRecentSearchs();
  }

  private onSearch(input: string): void {
    console.log('onSearch', input);
    let savedSearches: any[] = [];

    if (localStorage['recentSearches']) {
      savedSearches = JSON.parse(localStorage['recentSearches']);
    }

    console.log('savedSearchs', savedSearches);
    if (savedSearches.map(e => e.input).indexOf(input) == -1) {
      savedSearches = [{ input: input }, ...savedSearches];

      if (savedSearches.length > 5) {
        savedSearches.splice(5, 1);
      }

      localStorage['recentSearches'] = JSON.stringify(savedSearches);
    }
  }

  private onChange(input: string): void {
    console.log('onChange', input);
  }

  private onBlur(ev?: any): void {
    console.log('onBlur', ev);
  }

  private onFocus(ev?: any): void {
    console.log('onFocus', ev);
  }

  private onClear(ev?: any): void {
    console.log('onClear', ev);
  }

  private onEscape(ev?: any): void {
    console.log('onEscape', ev);
  }

  private loadRecentSearchs() {
    let savedSearches: ISearchBoxGroupItem[] = [];
    let templateSearches: ISearchBoxGroupItem[] = [];
    let results: ISearchBoxGroupItems[] = [];

    if (localStorage['recentSearches']) {
      savedSearches = JSON.parse(localStorage['recentSearches']);
      const test = this.onRenderRecent.bind(this);
      savedSearches.forEach(function(e) {
        e.onRenderColumns = test;
        e.type = 'recent';
      }, this);
    }

    Axios.get('http://localhost:5000/api/templates')
      .then(response => {
        const test = this.onRenderTemplates.bind(this);
        response.data.data.forEach((t: any) => {
          templateSearches = update(templateSearches, {
            $push: [Object.assign({ onRenderColumns: test, type: 'template', input: t.name }, t)]
          });
        }, this);

        results = [
          { key: 'recent', name: 'Recent Searches', onItemClick: this.onRecentItemClick, items: savedSearches },
          { key: 'favs', name: 'Favorites', onItemClick: this.onFavItemClick, items: [] },
          { key: 'templates', name: 'Searches Templates', onItemClick: this.onTemplateItemClick, items: templateSearches }
        ];

        this.setState({ groupItems: results });
      })
      .catch(error => {
        console.log(error);
      });
  }

  private onRecentItemClick(item: ISearchBoxGroupItem) {
    console.log('item click recent');
  }

  private onFavItemClick(item: ISearchBoxGroupItem) {
    console.log('item click fav');
  }

  private onTemplateItemClick(item: ISearchBoxGroupItem) {
    console.log('item click template');
  }

  private addFavClick(item: any, event: React.MouseEvent<HTMLAnchorElement | HTMLButtonElement | HTMLDivElement | BaseButton | Button>) {
    event.preventDefault();
    event.stopPropagation();

    item.oldOnRenderColumns = item.onRenderColumns;
    item.onRenderColumns = this.onRenderFavs.bind(this);

    console.log('item:', item);

    const groupIdx = item.type === 'recent' ? 0 : 2;
    const index = this.state.groupItems[groupIdx].items.findIndex(x => x.input == item.input);

    console.log('before', this.state.groupItems, index);

    let newgroupItems;
    if (groupIdx === 0) {
      newgroupItems = update(this.state.groupItems, { 0: { items: { $splice: [[index, 1]] } } });
    } else {
      newgroupItems = update(this.state.groupItems, { 2: { items: { $splice: [[index, 1]] } } });
    }

    const newgroupItems2 = update(newgroupItems, { 1: { items: { $push: [item] } } });

    console.log('new recent: ', newgroupItems2);

    this.setState({ groupItems: newgroupItems2 });
  }

  private delFavClick(item: any, event: React.MouseEvent<HTMLAnchorElement | HTMLButtonElement | HTMLDivElement | BaseButton | Button>) {
    event.preventDefault();
    event.stopPropagation();

    item.onRenderColumns = item.oldOnRenderColumns;

    console.log('item:', item);

    const groupIdx = item.type === 'recent' ? 0 : 2;
    const index = this.state.groupItems[1].items.findIndex(x => x.input == item.input);

    console.log('before', this.state.groupItems, index);

    const newgroupItems = update(this.state.groupItems, { 1: { items: { $splice: [[index, 1]] } } });

    let newgroupItems2;
    if (groupIdx === 0) {
      newgroupItems2 = update(newgroupItems, { 0: { items: { $push: [item] } } });
    } else {
      newgroupItems2 = update(newgroupItems, { 2: { items: { $push: [item] } } });
    }

    this.setState({ groupItems: newgroupItems2 });
  }

  private onRenderRecent(item: ISearchBoxGroupItem): IColumn[] {
    var _thiss = this;
    return [
      {
        key: 'input',
        name: 'Input',
        fieldName: 'input',
        minWidth: 300
      },
      {
        key: 'icon',
        name: 'Icon',
        minWidth: 80,
        maxWidth: 80,
        onRender: (item: any) => {
          return (
            <IconButton
              disabled={false}
              checked={false}
              iconProps={{ iconName: 'AddFavorite' }}
              title="FavoriteStarFill"
              ariaLabel="FavoriteStarFill"
              onClick={event => _thiss.addFavClick(item, event)}
            />
          );
        }
      }
    ];
  }

  private onRenderTemplates(item: ISearchBoxGroupItem): IColumn[] {
    var _this = this;
    return [
      {
        key: 'name',
        name: 'Name',
        fieldName: 'name',
        minWidth: 300
      },
      {
        key: 'icon',
        name: 'Icon',
        minWidth: 80,
        maxWidth: 80,
        onRender: (item: any) => {
          return (
            <IconButton
              disabled={false}
              checked={false}
              iconProps={{ iconName: 'AddFavorite' }}
              title="FavoriteStarFill"
              ariaLabel="FavoriteStarFill"
              onClick={event => _this.addFavClick(item, event)}
            />
          );
        }
      }
    ];
  }

  private onRenderFavs(item: ISearchBoxGroupItem): IColumn[] {
    return [
      {
        key: 'input',
        name: 'Input',
        fieldName: 'input',
        minWidth: 300
      },
      {
        key: 'icon',
        name: 'Icon',
        minWidth: 80,
        maxWidth: 80,
        iconName: 'FavoriteStarFill',
        isIconOnly: true,
        onRender: (item: any) => {
          return (
            <IconButton
              disabled={false}
              checked={false}
              iconProps={{ iconName: 'Unfavorite' }}
              title="Unfavorite"
              ariaLabel="Unfavorite"
              onClick={event => this.delFavClick(item, event)}
            />
          );
        }
      }
    ];
  }
}
export default SearchBoxDemo;
