import Axios from 'axios';

import FileSaver from 'file-saver';

export interface IExportCommand {
  urlCommand: string;
  contentType: string;
  fileType: string;
}

export function executeExportCommand(url: string, id: string, command: IExportCommand, ids: string[]) {
  let idsUriValues: string | undefined = undefined;

  if (!ids || ids.length === 0) {
    console.log('Nothing to export.');
    return;
  }

  ids.forEach(id => {
    idsUriValues = idsUriValues ? idsUriValues + `&ids=${id}` : `?ids=${id}`;
  });

  const commandUrl = `${url}/${command.urlCommand}/${id}/${command.fileType}${idsUriValues}`;

  console.log(`Invoking ${commandUrl}`);

  Axios.get(commandUrl, {
    headers: { accept: command.contentType },
    responseType: 'blob'
  }).then(response => {
    const blob = new Blob([response.data]);
    FileSaver.saveAs(blob, `Exported_${id}.${command.fileType}`);
  });
}
