import {
  ITemplateFieldValueDto,
  ITemplateFormRow,
  ITemplateDto,
  ITemplateFormSearchObject
} from '../components/TemplateForm/TemplateForm.types';

import { ITemplateFormState } from '../components/TemplateForm/TemplateForm.base';

import { FieldTypeEnum } from './Utils.types';

export function toTemplateResult(dto: ITemplateDto): string {
  const properties: ITemplateFormRow[] = [];

  dto.data.forEach(element => {
    const operations: ITemplateFieldValueDto[] = element.operations;

    let operation: string | number = '';

    operations.forEach(operationElement => {
      if (operationElement.selected) {
        operation = operationElement.key;
      }
    });

    const values: any[] = [];

    if (element.field === FieldTypeEnum.LOOKUP || element.field === FieldTypeEnum.PICKUP) {
      element.values.forEach(value => {
        if (value.selected) {
          const fieldValue = {
            key: value.key,
            text: value.text
          };
          values.push(fieldValue);
        }
      });
    } else {
      const fieldValue = {
        key: element.values[0].key,
        text: element.values[0].text
      };
      values.push(fieldValue);
    }

    const property: ITemplateFormRow = {
      id: element.id,
      name: element.name,
      isSystemField: element.isSystemField,
      operation: operation,
      values: values
    };

    properties.push(property);
  });

  const jsonString = JSON.stringify({
    id: dto.id,
    name: dto.name,
    properties: properties,
    main: dto.main,
    displayColumns: dto.displayColumns
  });

  console.log('Dto -> Template:', jsonString);

  return encodeURIComponent(jsonString);
}

export function formToTemplateResult(state: ITemplateFormState, result: ITemplateFormSearchObject): string {
  if (result === null) {
    console.log('result empty');
    return '';
  }

  logResult(state, result);

  let properties: ITemplateFormRow[] = [];

  result.values.forEach((row: ITemplateFormRow, key: number) => {
    properties.push(row);
  });

  const jsonResult = JSON.stringify({
    id: state.id,
    name: state.name,
    properties: properties,
    main: result.main,
    displayColumns: result.displayColumns
  });

  console.log('Data Submited to server in raw format:', jsonResult);

  return encodeURIComponent(jsonResult);
}

function logResult(state: ITemplateFormState, result: ITemplateFormSearchObject): void {
  if (!result || !result.values) {
    console.log('result empty');
    return;
  }

  let msg = '\n\n------------------------\n';
  msg += '      Form Values       \n';
  msg += '------------------------';
  msg += '\n   Id: ' + state.id;
  msg += '\n   Name: ' + state.name;
  msg += '\n   Main Values: ';
  result.main.forEach(element => {
    msg += '\n\t Id:' + element.id + '; Name:' + element.name;
    if (element.values != null) {
      element.values.forEach((value: any) => {
        msg += '\n\t\t Key:' + value.key + '; Value:' + value.text;
      });
    }
  });
  result.values.forEach((row: ITemplateFormRow, key: number) => {
    msg += '\n   ID: ' + row.id + '\n';
    msg += 'Name: ' + row.name + '\n';
    msg += 'System Field: ' + row.isSystemField + '\n';
    msg += '   Operation ID: ' + row.operation + '\n';

    let valuesMsg = '   Values:\n';
    row.values.forEach((item: any, key: number) => {
      valuesMsg += '\t' + item.key + '\n';
      valuesMsg += '\t' + item.text + '\n';
    });
    msg += valuesMsg;
    msg += '------------------------';
  });
  msg += '\n   Columns to Display: ' + result.displayColumns + '\n';
  var displayMsg = '\nDisplay Properties:\n';
  result.displayColumns.forEach(element => {
    displayMsg += `\tkey=${element.key}; name=${element.text};isSystemField=${element.isSystemField}\n`;
  });
  msg += displayMsg + '\n\n';
  console.log(msg);
}
