import * as React from 'react';

import { storiesOf } from '@storybook/react';

import { SelectionMode, Selection, IObjectWithKey } from 'office-ui-fabric-react/lib/DetailsList';

import 'office-ui-fabric-react/dist/css/fabric.min.css';

import { ContextualMenuItemType, IContextualMenuProps } from 'office-ui-fabric-react/lib/ContextualMenu';

import { List } from '../..';

import 'office-ui-fabric-react/dist/css/fabric.min.css';
import './List.stories.css';

let selection = new Selection({
  getKey: (item: IObjectWithKey, index?: number | undefined): string | number => {
    console.log('item getKey', item, index, (item as any).id);
    return item && (item as any).id ? (item as any).id : `${index}`;
  },
  onSelectionChanged: () => {
    console.log(selection.getSelection());
  }
});

storiesOf('List', module)
  .add('Default', () => (
    <List
      getUrl={getUrl}
      handleResponse={handleResponse}
      onCustomBuildColumns={onCustomBuildColumns}
      selectionMode={SelectionMode.single}
      enableSearch={true}
      enableSort={true}
      height={'800px'}
    />
  ))
  .add('No search box, no selection', () => (
    <List
      getUrl={getUrl}
      handleResponse={handleResponse}
      onCustomBuildColumns={onCustomBuildColumns}
      selectionMode={SelectionMode.none}
      enableSearch={false}
      enableSort={false}
      height={'800px'}
    />
  ))
  .add('Automatic columns with sorting and multiple selection', () => (
    <List
      getUrl={getUrl}
      handleResponse={handleResponse}
      selectionMode={SelectionMode.multiple}
      enableSearch={true}
      enableSort={true}
      height={'800px'}
    />
  ))
  .add('On row Double Click', () => (
    <List
      getUrl={getUrl}
      handleResponse={handleResponse}
      onRenderRow={onRenderRow}
      selectionMode={SelectionMode.none}
      enableSearch={true}
      enableSort={true}
      height={'800px'}
    />
  ))
  .add('With a Context Menu', () => (
    <List
      getUrl={getUrl}
      handleResponse={handleResponse}
      selectionMode={SelectionMode.single}
      height={'800px'}
      onItemContextMenu={onItemContextMenu}
      overrideDevice={true}
      underlined={true}
    />
  ));

function isNull(value: any) {
  return value == null || value === 'null' || value == undefined;
}

function handleResponse(items: any[]) {
  return items;
}

function getUrl(search: string, page: number, sortBy?: string | undefined, sortDesc?: boolean | undefined): string {
  const qValue = isNull(search) ? '' : `&q=${search}`;
  const sortByValue = isNull(sortBy) ? '' : `&_sort=${sortBy}`;
  let sortDescValue = '';

  if (!isNull(sortDesc)) {
    sortDescValue = sortDesc ? '&_order=desc' : '&_order=asc';
  }

  const url = `http://localhost:5000/api/documents?_start=${page}&_limit=20${qValue}${sortByValue}${sortDescValue}`;
  console.log(url);
  return url;
}

function onCustomBuildColumns() {
  console.log('Set custom columns');
  return [
    {
      key: 'Barcode',
      name: 'Barcode',
      fieldName: 'Barcode',
      minWidth: 210,
      maxWidth: 350,
      isRowHeader: true,
      isResizable: false,
      isSorted: true,
      isSortedDescending: false,
      sortAscendingAriaLabel: 'Sorted A to Z',
      sortDescendingAriaLabel: 'Sorted Z to A',
      data: 'string',
      isPadded: true
    }
  ];
}

function onRenderRow(props: any, defaultRender: any) {
  /*   console.log("original theme: ", props)
    props.theme = listTheme;
    console.log("new theme: ", props) */
  return <div onDoubleClick={event => onRowClick(props.item.key, props.item.name, event)}>{defaultRender(props)}</div>;
}

function onRowClick(id: string, name: string, e: any) {
  alert('Row clicked: ' + id + '  -  ' + name);
}

function onItemContextMenu(item: any, index: number, ev: Event | undefined): IContextualMenuProps {
  const empty = {} as IContextualMenuProps;

  if (index <= -1) {
    return empty;
  }

  const contextualMenuProps: IContextualMenuProps = {
    target: ev!.target as HTMLElement,
    items: [
      {
        key: 'section' + item.key,
        itemType: ContextualMenuItemType.Section,
        sectionProps: {
          key: 'sectionProps' + item.key + '1',
          topDivider: true,
          bottomDivider: true,
          title: 'Actions',
          items: [
            {
              key: 'Mail' + item.key,
              text: 'Mail',
              iconProps: {
                iconName: 'Mail'
              },
              onClick: () => console.log(item)
            },
            {
              key: 'deleteItem' + item.key,
              text: 'Delete',
              iconProps: {
                iconName: 'Delete'
              },
              onClick: () => console.log(item)
            }
          ]
        }
      },
      {
        key: 'section2' + item.key,
        itemType: ContextualMenuItemType.Section,
        sectionProps: {
          key: 'sectionProps' + item.key + '2',
          title: 'Other Actions',
          items: [
            {
              key: 'share' + item.key,
              text: 'Share',
              iconProps: {
                iconName: 'Share'
              },
              onClick: () => console.log(item)
            },
            {
              key: 'print' + item.key,
              text: 'Print',
              iconProps: {
                iconName: 'Print'
              },
              onClick: () => console.log(item)
            }
          ]
        }
      }
    ]
  };

  return contextualMenuProps;
}
