import * as React from 'react';

import { storiesOf } from '@storybook/react';

import { TemplateAdminForm } from './TemplateAdminForm';

import 'office-ui-fabric-react/dist/css/fabric.min.css';

const URL_BASE = 'http://localhost:5000/api';

storiesOf('TemplateAdminForm', module)
  .add('New Mode', () => (
    <TemplateAdminForm
      baseUrl={URL_BASE}
      onCancel={onCancel}
      onSubmitSuccess={response => console.log(response)}
      onSubmitError={response => console.log(response)}
    />
  ))
  .add('New Mode without Display Properties', () => (
    <TemplateAdminForm
      baseUrl={URL_BASE}
      onCancel={onCancel}
      allowDisplayProperties={false}      
      onSubmitSuccess={response => console.log(response)}
      onSubmitError={response => console.log(response)}
    />
  ))  
  .add('Edit Mode', () => (
    <TemplateAdminForm
      baseUrl={URL_BASE}
      id="1"
      onCancel={onCancel}
      onSubmitSuccess={response => console.log(response)}
      onSubmitError={response => console.log(response)}
    />
  ))
  .add('Edit Mode without Display Properties', () => (
    <TemplateAdminForm
      baseUrl={URL_BASE}
      id="1"
      allowDisplayProperties={false}
      onCancel={onCancel}
      onSubmitSuccess={response => console.log(response)}
      onSubmitError={response => console.log(response)}
    />
  ))
  .add('Edit Mode without Menu selection', () => (
    <TemplateAdminForm
      baseUrl={URL_BASE}
      id="1"
      allowMenus={false}
      onCancel={onCancel}
      onSubmitSuccess={response => console.log(response)}
      onSubmitError={response => console.log(response)}
    />
  ))
  .add('Edit With Panel Titles', () => (
    <TemplateAdminForm
      baseUrl={URL_BASE}
      id="1"
      onCancel={onCancel}
      onSubmitSuccess={response => console.log(response)}
      onSubmitError={response => console.log(response)}
      titleOnPanels={true}
    />
  ))
  .add('Edit with Custom Labels', () => (
    <TemplateAdminForm
      baseUrl={URL_BASE}
      id="1"
      labelTitleEdit="Custom Label for Edit Template"
      onCancel={onCancel}
      onSubmitSuccess={response => console.log(response)}
      onSubmitError={response => console.log(response)}
    />
  ))
  .add('Edit Mode with Dynamic translations', () => (
    <TemplateAdminForm
      baseUrl={URL_BASE}
      id="1"
      getDynamicTranslation={getDynamicTranslation}
      onCancel={onCancel}
      onSubmitSuccess={response => console.log(response)}
      onSubmitError={response => console.log(response)}
    />
  ));

function getDynamicTranslation(key: string): string {
  return key + '_translated';
}

function onCancel(): void {
  console.log('onCancel ...');
}
