import * as React from 'react';

import { storiesOf } from '@storybook/react';

import { TemplateForm } from './TemplateForm';

import { RenderType } from './TemplateForm.types';

import 'office-ui-fabric-react/dist/css/fabric.min.css';
import Axios from 'axios';

const URL_BASE = 'http://localhost:5000/api/templates';
const URL_DOCUMENTS = 'http://localhost:5000/api/documents';

storiesOf('TemplateForm', module)
  .add('Default', () => <TemplateForm user="admin" url={URL_BASE + '/1'} onCancel={onCancel} onSubmit={onSubmit} />)
  .add('Default with Custom Labels', () => (
    <TemplateForm
      user="admin"
      url={URL_BASE + '/1'}
      onCancel={onCancel}
      onSubmit={onSubmit}
      labelCmdBarSearch="Custom Search"
      labelCmdBarCancel="Custom Cancel"
    />
  ))
  .add('Rendered on a Dialog', () => (
    <TemplateForm
      user="admin"
      url={URL_BASE + '/1'}
      onCancel={onCancel}
      onSubmit={onSubmit}
      renderType={RenderType.DIALOG}
      hideExternalSurface={false}
    />
  ))
  .add('Rendered on a Dialog with Custom Labels', () => (
    <TemplateForm
      user="admin"
      url={URL_BASE + '/1'}
      onCancel={onCancel}
      onSubmit={onSubmit}
      renderType={RenderType.DIALOG}
      hideExternalSurface={false}
      labelCmdBarSearch="Custom Search"
      labelCmdBarCancel="Custom Cancel"
    />
  ))
  .add('Rendered on a Panel', () => (
    <TemplateForm
      user="admin"
      url={URL_BASE + '/1'}
      onCancel={onCancel}
      onSubmit={onSubmit}
      renderType={RenderType.PANEL}
      hideExternalSurface={false}
    />
  ))
  .add('Rendered on a Panel  Custom Labels', () => (
    <TemplateForm
      user="admin"
      url={URL_BASE + '/1'}
      onCancel={onCancel}
      onSubmit={onSubmit}
      renderType={RenderType.PANEL}
      hideExternalSurface={false}
      labelCmdBarSearch="Custom Search"
      labelCmdBarCancel="Custom Cancel"
    />
  ));

function onSubmit(formAsJsonEncoded: string) {
  console.log('Encoded Json:', formAsJsonEncoded);
  const url = `${URL_DOCUMENTS}?properties=${formAsJsonEncoded}`;
  Axios.get(url)
    .then(response => {
      console.log('Search Returned:', response.data);
    })
    .catch(error => console.log(error));
}

function onCancel(): void {
  console.log('onCancel ...');
}
